@@ -11,6 +11,7 @@ import logging
 import os
 import platform
 import re
+import struct
 import sys
 import sysconfig
 import warnings
@@ -18,6 +19,7 @@ from collections import OrderedDict, namedtuple
 from string import digits
 
 VersionInfo = namedtuple("VersionInfo", ["major", "minor", "micro", "releaselevel", "serial"])  # noqa: PYI024
+LOGGER = logging.getLogger(__name__)
 
 
 def _get_path_extensions():
@@ -28,7 +30,7 @@ EXTENSIONS = _get_path_extensions()
 _CONF_VAR_RE = re.compile(r"\{\w+\}")
 
 
-class PythonInfo:
+class PythonInfo:  # noqa: PLR0904
     """Contains information for a Python interpreter."""
 
     def __init__(self) -> None:  # noqa: PLR0915
@@ -43,7 +45,10 @@ class PythonInfo:
 
         # this is a tuple in earlier, struct later, unify to our own named tuple
         self.version_info = VersionInfo(*sys.version_info)
-        self.architecture = 64 if sys.maxsize > 2**32 else 32
+        # Use the same implementation as found in stdlib platform.architecture
+        # to account for platforms where the maximum integer is not equal the
+        # pointer size.
+        self.architecture = 32 if struct.calcsize("P") == 4 else 64  # noqa: PLR2004
 
         # Used to determine some file names.
         # See `CPython3Windows.python_zip()`.
@@ -51,6 +56,7 @@ class PythonInfo:
 
         self.version = sys.version
         self.os = os.name
+        self.free_threaded = sysconfig.get_config_var("Py_GIL_DISABLED") == 1
 
         # information about the prefix - determines python home
         self.prefix = abs_path(getattr(sys, "prefix", None))  # prefix we think
@@ -112,12 +118,16 @@ class PythonInfo:
 
         config_var_keys = set()
         for element in self.sysconfig_paths.values():
-            for k in _CONF_VAR_RE.findall(element):
-                config_var_keys.add(k[1:-1])
+            config_var_keys.update(k[1:-1] for k in _CONF_VAR_RE.findall(element))
         config_var_keys.add("PYTHONFRAMEWORK")
 
         self.sysconfig_vars = {i: sysconfig.get_config_var(i or "") for i in config_var_keys}
 
+        if "TCL_LIBRARY" in os.environ:
+            self.tcl_lib, self.tk_lib = self._get_tcl_tk_libs()
+        else:
+            self.tcl_lib, self.tk_lib = None, None
+
         confs = {
             k: (self.system_prefix if v is not None and v.startswith(self.prefix) else v)
             for k, v in self.sysconfig_vars.items()
@@ -127,9 +137,62 @@ class PythonInfo:
         self.max_size = getattr(sys, "maxsize", getattr(sys, "maxint", None))
         self._creators = None
 
+    @staticmethod
+    def _get_tcl_tk_libs():
+        """
+        Detects the tcl and tk libraries using tkinter.
+
+        This works reliably but spins up tkinter, which is heavy if you don't need it.
+        """
+        tcl_lib, tk_lib = None, None
+        try:
+            import tkinter as tk  # noqa: PLC0415
+        except ImportError:
+            pass
+        else:
+            try:
+                tcl = tk.Tcl()
+                tcl_lib = tcl.eval("info library")
+
+                # Try to get TK library path directly first
+                try:
+                    tk_lib = tcl.eval("set tk_library")
+                    if tk_lib and os.path.isdir(tk_lib):
+                        pass  # We found it directly
+                    else:
+                        tk_lib = None  # Reset if invalid
+                except tk.TclError:
+                    tk_lib = None
+
+                # If direct query failed, try constructing the path
+                if tk_lib is None:
+                    tk_version = tcl.eval("package require Tk")
+                    tcl_parent = os.path.dirname(tcl_lib)
+
+                    # Try different version formats
+                    version_variants = [
+                        tk_version,  # Full version like "8.6.12"
+                        ".".join(tk_version.split(".")[:2]),  # Major.minor like "8.6"
+                        tk_version.split(".")[0],  # Just major like "8"
+                    ]
+
+                    for version in version_variants:
+                        tk_lib_path = os.path.join(tcl_parent, f"tk{version}")
+                        if not os.path.isdir(tk_lib_path):
+                            continue
+                        # Validate it's actually a TK directory
+                        if os.path.exists(os.path.join(tk_lib_path, "tk.tcl")):
+                            tk_lib = tk_lib_path
+                            break
+
+            except tk.TclError:
+                pass
+
+        return tcl_lib, tk_lib
+
     def _fast_get_system_executable(self):
         """Try to get the system executable by just looking at properties."""
-        if self.real_prefix or (
+        if self.real_prefix or (  # noqa: PLR1702
             self.base_prefix is not None and self.base_prefix != self.prefix
         ):  # if this is a virtual environment
             if self.real_prefix is None:
@@ -175,8 +238,8 @@ class PythonInfo:
         with warnings.catch_warnings():  # disable warning for PEP-632
             warnings.simplefilter("ignore")
             try:
-                from distutils import dist
-                from distutils.command.install import SCHEME_KEYS
+                from distutils import dist  # noqa: PLC0415
+                from distutils.command.install import SCHEME_KEYS  # noqa: PLC0415
             except ImportError:  # if removed or not installed ignore
                 return {}
 
@@ -214,7 +277,9 @@ class PythonInfo:
         return self.base_prefix is not None
 
     def sysconfig_path(self, key, config_var=None, sep=os.sep):
-        pattern = self.sysconfig_paths[key]
+        pattern = self.sysconfig_paths.get(key)
+        if pattern is None:
+            return ""
         if config_var is None:
             config_var = self.sysconfig_vars
         else:
@@ -225,7 +290,7 @@ class PythonInfo:
 
     def creators(self, refresh=False):  # noqa: FBT002
         if self._creators is None or refresh is True:
-            from virtualenv.run.plugin.creators import CreatorSelector
+            from virtualenv.run.plugin.creators import CreatorSelector  # noqa: PLC0415
 
             self._creators = CreatorSelector.for_interpreter(self)
         return self._creators
@@ -254,9 +319,6 @@ class PythonInfo:
     def system_exec_prefix(self):
         return self.real_prefix or self.base_exec_prefix or self.exec_prefix
 
-    def __unicode__(self):
-        return repr(self)
-
     def __repr__(self) -> str:
         return "{}({!r})".format(
             self.__class__.__name__,
@@ -293,17 +355,22 @@ class PythonInfo:
 
     @property
     def spec(self):
-        return "{}{}-{}".format(self.implementation, ".".join(str(i) for i in self.version_info), self.architecture)
+        return "{}{}{}-{}".format(
+            self.implementation,
+            ".".join(str(i) for i in self.version_info),
+            "t" if self.free_threaded else "",
+            self.architecture,
+        )
 
     @classmethod
     def clear_cache(cls, app_data):
         # this method is not used by itself, so here and called functions can import stuff locally
-        from virtualenv.discovery.cached_py_info import clear
+        from virtualenv.discovery.cached_py_info import clear  # noqa: PLC0415
 
         clear(app_data)
         cls._cache_exe_discovery.clear()
 
-    def satisfies(self, spec, impl_must_match):  # noqa: C901
+    def satisfies(self, spec, impl_must_match):  # noqa: C901, PLR0911
         """Check if a given specification can be satisfied by the this python interpreter instance."""
         if spec.path:
             if self.executable == os.path.abspath(spec.path):
@@ -329,6 +396,9 @@ class PythonInfo:
         if spec.architecture is not None and spec.architecture != self.architecture:
             return False
 
+        if spec.free_threaded is not None and spec.free_threaded != self.free_threaded:
+            return False
+
         for our, req in zip(self.version_info[0:3], (spec.major, spec.minor, spec.micro)):
             if req is not None and our is not None and our != req:
                 return False
@@ -348,7 +418,7 @@ class PythonInfo:
         return cls._current
 
     @classmethod
-    def current_system(cls, app_data=None):
+    def current_system(cls, app_data=None) -> PythonInfo:
         """
         This locates the current host interpreter information. This might be different than what we run into in case
         the host python has been upgraded from underneath us.
@@ -362,7 +432,7 @@ class PythonInfo:
         return json.dumps(self._to_dict(), indent=2)
 
     def _to_dict(self):
-        data = {var: (getattr(self, var) if var not in ("_creators",) else None) for var in vars(self)}
+        data = {var: (getattr(self, var) if var != "_creators" else None) for var in vars(self)}
 
         data["version_info"] = data["version_info"]._asdict()  # namedtuple to dictionary
         return data
@@ -379,7 +449,7 @@ class PythonInfo:
     ):
         """Given a path to an executable get the python information."""
         # this method is not used by itself, so here and called functions can import stuff locally
-        from virtualenv.discovery.cached_py_info import from_exe
+        from virtualenv.discovery.cached_py_info import from_exe  # noqa: PLC0415
 
         env = os.environ if env is None else env
         proposed = from_exe(cls, app_data, exe, env=env, raise_on_error=raise_on_error, ignore_cache=ignore_cache)
@@ -387,10 +457,10 @@ class PythonInfo:
         if isinstance(proposed, PythonInfo) and resolve_to_host:
             try:
                 proposed = proposed._resolve_to_system(app_data, proposed)  # noqa: SLF001
-            except Exception as exception:  # noqa: BLE001
+            except Exception as exception:
                 if raise_on_error:
                     raise
-                logging.info("ignore %s due cannot resolve system due to %r", proposed.original_executable, exception)
+                LOGGER.info("ignore %s due cannot resolve system due to %r", proposed.original_executable, exception)
                 proposed = None
         return proposed
 
@@ -416,12 +486,12 @@ class PythonInfo:
             if prefix in prefixes:
                 if len(prefixes) == 1:
                     # if we're linking back to ourselves accept ourselves with a WARNING
-                    logging.info("%r links back to itself via prefixes", target)
+                    LOGGER.info("%r links back to itself via prefixes", target)
                     target.system_executable = target.executable
                     break
                 for at, (p, t) in enumerate(prefixes.items(), start=1):
-                    logging.error("%d: prefix=%s, info=%r", at, p, t)
-                logging.error("%d: prefix=%s, info=%r", len(prefixes) + 1, prefix, target)
+                    LOGGER.error("%d: prefix=%s, info=%r", at, p, t)
+                LOGGER.error("%d: prefix=%s, info=%r", len(prefixes) + 1, prefix, target)
                 msg = "prefixes are causing a circle {}".format("|".join(prefixes.keys()))
                 raise RuntimeError(msg)
             prefixes[prefix] = target
@@ -436,9 +506,9 @@ class PythonInfo:
     def discover_exe(self, app_data, prefix, exact=True, env=None):  # noqa: FBT002
         key = prefix, exact
         if key in self._cache_exe_discovery and prefix:
-            logging.debug("discover exe from cache %s - exact %s: %r", prefix, exact, self._cache_exe_discovery[key])
+            LOGGER.debug("discover exe from cache %s - exact %s: %r", prefix, exact, self._cache_exe_discovery[key])
             return self._cache_exe_discovery[key]
-        logging.debug("discover exe for %s in %s", self, prefix)
+        LOGGER.debug("discover exe for %s in %s", self, prefix)
         # we don't know explicitly here, do some guess work - our executable name should tell
         possible_names = self._find_possible_exe_names()
         possible_folders = self._find_possible_folders(prefix)
@@ -454,7 +524,7 @@ class PythonInfo:
             info = self._select_most_likely(discovered, self)
             folders = os.pathsep.join(possible_folders)
             self._cache_exe_discovery[key] = info
-            logging.debug("no exact match found, chosen most similar of %s within base folders %s", info, folders)
+            LOGGER.debug("no exact match found, chosen most similar of %s within base folders %s", info, folders)
             return info
         msg = "failed to detect {} in {}".format("|".join(possible_names), os.pathsep.join(possible_folders))
         raise RuntimeError(msg)
@@ -473,7 +543,7 @@ class PythonInfo:
                 if item == "version_info":
                     found, searched = ".".join(str(i) for i in found), ".".join(str(i) for i in searched)
                 executable = info.executable
-                logging.debug("refused interpreter %s because %s differs %s != %s", executable, item, found, searched)
+                LOGGER.debug("refused interpreter %s because %s differs %s != %s", executable, item, found, searched)
                 if exact is False:
                     discovered.append(info)
                 break
@@ -525,10 +595,14 @@ class PythonInfo:
         for name in self._possible_base():
             for at in (3, 2, 1, 0):
                 version = ".".join(str(i) for i in self.version_info[:at])
-                for arch in [f"-{self.architecture}", ""]:
-                    for ext in EXTENSIONS:
-                        candidate = f"{name}{version}{arch}{ext}"
-                        name_candidate[candidate] = None
+                mods = [""]
+                if self.free_threaded:
+                    mods.append("t")
+                for mod in mods:
+                    for arch in [f"-{self.architecture}", ""]:
+                        for ext in EXTENSIONS:
+                            candidate = f"{name}{version}{mod}{arch}{ext}"
+                            name_candidate[candidate] = None
         return list(name_candidate.keys())
 
     def _possible_base(self):
@@ -543,7 +617,7 @@ class PythonInfo:
         for base in possible_base:
             lower = base.lower()
             yield lower
-            from virtualenv.info import fs_is_case_sensitive
+            from virtualenv.info import fs_is_case_sensitive  # noqa: PLC0415
 
             if fs_is_case_sensitive():
                 if base != lower:
